@@ -8,25 +8,30 @@
 #   The (three-clause) BSD License
 #
 package MyModel;
+
 use Moose;
-use Test::More;
-use IO::Socket::INET;
-use ElasticSearchX::Model;
-use Search::Elasticsearch;
+
 use version;
 
+use ElasticSearchX::Model;
+use IO::Socket::INET;
+use Search::Elasticsearch;
+use Test::More;
+
 index twitter => ( namespace => 'MyModel' );
 
 sub testing {
     my $class = shift;
-    unless ( IO::Socket::INET->new('127.0.0.1:9900') ) {
+
+    my $bind_to = $ENV{ES} || '127.0.0.1:9900';
+    unless ( IO::Socket::INET->new($bind_to) ) {
         plan skip_all =>
-            'Requires an Elasticsearch server running on port 9900';
+            "Requires an Elasticsearch server running on port $bind_to";
     }
 
     my $model = $class->new(
         es => Search::Elasticsearch->new(
-            nodes => $ENV{ES} || "localhost:9900",
+            nodes => $bind_to,
 
             # trace_to => "Stderr",
         )
